@@ -1,6 +1,6 @@
 /*
 integrit - file integrity verification system
-Copyright (C) 2005 Ed L. Cashin
+Copyright (C) 2006 Ed L. Cashin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -32,7 +32,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #else
 #error No stdint.h or inttypes.h found.
 #endif
-#include	"gnupg/sha1.h"
+#include	"digest.h"
 #include	"hexprint_p.h"
 #include	"elcerror_p.h"
 #include	"elcerror.h"
